Learn R Programming

mergenstudio (version 1.0)

addin_mergenchat: Run Mergen Chat

Description

Run the Mergen Chat Shiny App as a background job and show it in the viewer pane

Usage

addin_mergenchat(host = getOption("shiny.host", "127.0.0.1"))

Value

This function has no return value.

Arguments

host

The IPv4 address that the application should listen on. Defaults to the shiny.host option, if set, or "127.0.0.1" if not. See Details.

Examples

Run this code
# Call the function as an RStudio addin
if(interactive()){
addin_mergenchat()
}

Run the code above in your browser using DataLab