powered by
Run the Mergen Chat Shiny App as a background job and show it in the viewer pane
addin_mergenchat(host = getOption("shiny.host", "127.0.0.1"))
This function has no return value.
The IPv4 address that the application should listen on. Defaults to the shiny.host option, if set, or "127.0.0.1" if not. See Details.
shiny.host
"127.0.0.1"
# Call the function as an RStudio addin if(interactive()){ addin_mergenchat() }
Run the code above in your browser using DataLab